Struct ZxdgImportedV1
pub struct ZxdgImportedV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
an imported surface handle
An xdg_imported object represents an imported reference to surface exported by some client. A client can use this interface to manipulate relationships between its own surfaces and the imported surface.
See also the Event enum for this interface.
Implementations
impl ZxdgImportedV1
impl ZxdgImportedV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy the xdg_imported object
Notify the compositor that it will no longer use the xdg_imported object. Any relationship that may have been set up will at this point be invalidated.
pub fn set_parent_of(&self, surface: &WlSurface)
pub fn set_parent_of(&self, surface: &WlSurface)
set as the parent of some surface
Set the imported surface as the parent of some surface of the client. The passed surface must be a toplevel xdg_surface. Calling this function sets up a surface to surface relation with the same stacking and positioning semantics as xdg_surface.set_parent.